==> goffice-0.3.2.tar.bz2: goffice-0.3.2/goffice/graph/gog-smoothed-curve.h <==
/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
/*
 * gog-smoothed-curve.h :  
 *
 * Copyright (C) 2006 Jean Brefort (jean.brefort@normalesup.org)
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of version 2 of the GNU General Public
 * License as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
 * USA
 */

#ifndef GOG_SMOOTHED_CURVE_H
#define GOG_SMOOTHED_CURVE_H

#include <goffice/graph/gog-trend-line.h>
#include <goffice/graph/gog-series.h>
#include <goffice/graph/gog-data-set.h>

G_BEGIN_DECLS

struct  _GogSmoothedCurve {
	GogTrendLine	base;
	
	GogSeries 	  *series;
	double *x, *y;
	unsigned nb;
};

typedef struct {
	GogTrendLineClass base;

} GogSmoothedCurveClass;

#define GOG_SMOOTHED_CURVE_TYPE	(gog_smoothed_curve_get_type ())
#define GOG_SMOOTHED_CURVE(o)	(G_TYPE_CHECK_INSTANCE_CAST ((o), GOG_SMOOTHED_CURVE_TYPE, GogSmoothedCurve))
#define IS_GOG_SMOOTHED_CURVE(o)	(G_TYPE_CHECK_INSTANCE_TYPE ((o), GOG_SMOOTHED_CURVE_TYPE))

GType gog_smoothed_curve_get_type (void);

G_END_DECLS

#endif /* GOG_SMOOTHED_CURVE_H */

==> goffice-0.7.5.tar.bz2: goffice-0.7.5/goffice/graph/gog-smoothed-curve.h <==
/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
/*
 * gog-smoothed-curve.h :  
 *
 * Copyright (C) 2006 Jean Brefort (jean.brefort@normalesup.org)
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of version 2 of the GNU General Public
 * License as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
 * USA
 */

#ifndef GOG_SMOOTHED_CURVE_H
#define GOG_SMOOTHED_CURVE_H

#include <goffice/graph/gog-trend-line.h>
#include <goffice/graph/gog-series.h>
#include <goffice/graph/gog-data-set.h>

G_BEGIN_DECLS

struct  _GogSmoothedCurve {
	GogTrendLine	base;
	
	GogSeries 	  *series;
	double *x, *y;
	unsigned nb;
};

typedef struct {
	GogTrendLineClass base;

} GogSmoothedCurveClass;

#define GOG_TYPE_SMOOTHED_CURVE	(gog_smoothed_curve_get_type ())
#define GOG_SMOOTHED_CURVE(o)	(G_TYPE_CHECK_INSTANCE_CAST ((o), GOG_TYPE_SMOOTHED_CURVE, GogSmoothedCurve))
#define GOG_IS_SMOOTHED_CURVE(o)	(G_TYPE_CHECK_INSTANCE_TYPE ((o), GOG_TYPE_SMOOTHED_CURVE))

GType gog_smoothed_curve_get_type (void);

G_END_DECLS

#endif /* GOG_SMOOTHED_CURVE_H */
